==> geant4.10.00.tar.gz: geant4.10.00/examples/advanced/air_shower/src/UltraActionInitializer.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: UltraActionInitializer.cc 66241 2012-12-13 18:34:42Z gunter $
// GEANT4 tag $Name:  $
//
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#include "UltraActionInitializer.hh"

#include "UltraPrimaryGeneratorAction.hh"
#include "UltraRunAction.hh"
#include "UltraEventAction.hh"

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

UltraActionInitializer::UltraActionInitializer() : 
  G4VUserActionInitialization()
{;}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void UltraActionInitializer::Build() const 
{
  
  // primary generator
  SetUserAction(new UltraPrimaryGeneratorAction());

  //Thread-local RunAction: same class, but code controlled by IsMaster()
  SetUserAction(new UltraRunAction());
  SetUserAction(new UltraEventAction());
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void UltraActionInitializer::BuildForMaster() const
{ 
  //Thread-local RunAction: same class, but code controlled by IsMaster()
  SetUserAction(new UltraRunAction());
}

==> geant4.10.01.tar.gz: geant4.10.01/examples/advanced/air_shower/src/UltraActionInitializer.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: UltraActionInitializer.cc 66241 2012-12-13 18:34:42Z gunter $
// GEANT4 tag $Name:  $
//
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#include "UltraActionInitializer.hh"

#include "UltraPrimaryGeneratorAction.hh"
#include "UltraRunAction.hh"
#include "UltraEventAction.hh"
#include "G4GeneralParticleSource.hh"

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

UltraActionInitializer::UltraActionInitializer() : 
  G4VUserActionInitialization()
{
    //AND->3June2014, temporary to take into account new GPS
    //Create an instance of GPS in master so shared resources and messenger
    //exist in master.
    masterGPS = new G4GeneralParticleSource();
    //AND<-3June2014
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

UltraActionInitializer::~UltraActionInitializer() 
{
   delete masterGPS;
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void UltraActionInitializer::Build() const 
{
  
  // primary generator
  SetUserAction(new UltraPrimaryGeneratorAction());

  //Thread-local RunAction: same class, but code controlled by IsMaster()
  SetUserAction(new UltraRunAction());
  SetUserAction(new UltraEventAction());
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void UltraActionInitializer::BuildForMaster() const
{ 
  //Thread-local RunAction: same class, but code controlled by IsMaster()
  SetUserAction(new UltraRunAction());
}
